#ifndef SELECTIVE_WINDOW_H
#define SELECTIVE_WINDOW_H

// ***************************************************************************
// System Includes
// ***************************************************************************

// ***************************************************************************
// Project Includes
// ***************************************************************************

#include "StyleGuideDefs.h"         // Standard type and constant definitions.

// ***************************************************************************
// External Name Declarations
// ***************************************************************************

// ***************************************************************************
// External Variable Declarations
// ***************************************************************************

// ***************************************************************************
// Constant Definitions
// ***************************************************************************

// ***************************************************************************
// Type Definitions
// ***************************************************************************

// ***************************************************************************
// Class Definition
// ***************************************************************************

/**  
 * The main window.
 */
class tSelectiveWindow : public BWindow {
public:
  // Constant Definitions ====================================================

  // Type Definitions ========================================================

  // Attribute Definitions ===================================================

  // Member Function Definitions =============================================
 
  // Lifecycle ---------------------------------------------------------------

  /** 
   * Constructor. 
   * 
   * @param aDirRef The entry_ref of the directory that is displayed in the 
   *        selected Tracker window.
   * @param apMessage A standard B_REFS_RECEIVED BMessage that contains a
   *        messenger called "TrackerViewToken" to the Poses property of the
   *        selected Tracker window. Although the message may have other 
   *        contents (such as the entry_refs of the selected files from the
   *        current directory), they are ignored.
   */
  tSelectiveWindow(entry_ref aDirRef, BMessage* apMessage); 

  /** Automatically generated copy constructor. */
  // tSelectiveWindow(const tSelectiveWindow& arOld);

  /** Automatically generated destructor. */
  // virtual ~tSelectiveWindow();

  // Operators ---------------------------------------------------------------

  /** Automatically generated assignment operator. */
  // tSelectiveWindow& operator=(tSelectiveWindow& arRight);

  // Operations --------------------------------------------------------------

  /** Handles the messages that the window receives. */
  virtual void MessageReceived(BMessage* apMessage);

  // Access ------------------------------------------------------------------

  // Inquiry -----------------------------------------------------------------

protected:
  // Constant Definitions ====================================================

  // Type Definitions ========================================================

  // Attribute Definitions ===================================================

  // Member Function Definitions =============================================

private:
  // Constant Definitions ====================================================

  // Type Definitions ========================================================

  // Attribute Definitions ===================================================

  /** The entry_ref that was passed into our constructor. */
  entry_ref mTrackerDirRef;
  
  /** The BMessage* that was passed into our constructor. */
  BMessage* mpTrackerMessage;
  
  /** Pointer to the entry field for the selection pattern. */
  BTextControl* mpPatternText;

  // Member Function Definitions =============================================

  /** Makes the selection. */  
  void Select();

  /**
   * Determines whether a string matches a certain wildcard pattern. Matching
   * is not case-sensitive.
   *
   * @param apPattern The pattern. May contain the wildcards *, which matches
   *        any character zero or more times, and ?, which matches any single
   *        character.
   * @param apString The string to match.
   */
  bool IsMatch(const tChar* apPattern, const tChar* apString);
};

// ***************************************************************************
// Global Variable Declarations
// ***************************************************************************

// ***************************************************************************
// Inline Function Definitions
// ***************************************************************************

// ***************************************************************************
// Helper Function Declarations
// ***************************************************************************

// ***************************************************************************
// Global Function Declarations
// ***************************************************************************

#endif // SELECTIVE_WINDOW_H
